%%              Compute Torus Sections 
% Alistair Boettiger                                   Date Begun: 02/27/08
% Getz Lab                                         Complete Since: 02/27/08
% Functionally Complete                             Last Modified: 02/27/08

% NDVI_torus.m
%
%
% called by density_metrics.m
% Code computes 
%       - average NDVI value in number of specified toriodal sectors    
%       - in which ranked sector the predicted COM resides
%
% sector numbering (-pi:pi)
%                 3N/4
%          3N/4+1      3N/4-1
%         N-1              -
%       N                    N/2
%         1                -
%            2           -
%                 N/4
%

function [mean_ndvi, scor, sec_var] = NDVI_torus(A,segs,xc,yc,ri,ro,xf,yf);

% function testing parameters
%
%load NDVIs; A = double(NDVI(:,:,6));  segs =  9; xc = 50; yc = 40;  ri = 1; ro = 13; xf = 37; yf =41; B=A;


% set clouds and mountains to zeros for later exclusion; 
A(A==1)=0;
% figure(1); clf; pcolor(A); shading interp;
 
% Set up Distance and angle logical matrices 
    [a o] = size(A); nlats = 1:a; nlongs = 1:o;
    [Nlong Nlat] = meshgrid(nlongs-xc,nlats-yc);
    D = sqrt(Nlat.^2+Nlong.^2);   R = D>ri&D<ro;    % figure(2); clf; pcolor(double(R));  
    theta = linspace(-pi,pi,segs);  T = atan2(Nlat,Nlong);
    hit = zeros(segs,1); mean_ndvi = zeros(segs,1);
% Choose sectors 
for i=1:segs-1
    % Select sector and compute mean NDVI
    Ti = T>=theta(i) & T<theta(i+1); % figure(2); clf; pcolor(double(Ti));
    I = R&Ti;  % figure(2); clf; pcolor(double(I));
   %  B(I) = i/segs*4;
   if isempty( nonzeros(A(I)) )==1; % protect against cloud error
        mean_ndvi(i) = 0;  %  this may really slow up an already slow code
   else
        mean_ndvi(i) = mean(mean( nonzeros(A(I)) ));
   end
    %  In which sector is the predicted COM?
    fa = atan2(yf-yc,xf-xc); fd = (yf-yc).^2+(xf-xc).^2;
    hit(i) =   fa>theta(i) & fa<theta(i+1) &  fd > ri.^2 ;
end

    if isempty(nonzeros( A(D<=ri) ))==1; % avoid trying to av. empty sets
        cnt = 0; % set empty sets to 0
    else
        cnt = mean(mean( nonzeros(A(D<=ri)) ));
    end
mean_ndvi(segs) =  cnt;  % record value in center in last element of export

rank = sortrows([mean_ndvi [0:segs-1]']);
sec_var = std(mean_ndvi); 

% which sector was the hit (location of projected COM)?
sec = find(hit==1);  if isempty(sec)==1; sec =0 ; end;
% return the rank of the sector not the sector itself 
scor = find(rank(:,2)==sec); 

%         1..9 - 1   / 8 
scor = 2*(scor-1)/(segs-1)-1; % normalize -1 to 1


%  figure(3); clf; pcolor(B); shading flat; hold on;
%  plot(xf,yf,'k.');

