    %=================================================================%
    %                        Wiener Filter                            %
    %=================================================================%
 % Alistair Boettiger                                  Date Begun: 03/14/08
 % Getz Lab                                      Functional Since: 04/23/08 
 % Functionally Complete                            Last Modified: 01/06/10
 %
 % Wiener_filter_compsig.m
 %
 % Notes:
 % Wiener Paper Main text: TABLE 1
 % Compare all signals for specific window gaps
 %
 % All 
 % Mov
 % COM only
 %    
 %  
 %
 %
 %
 %
 % loads data of normalized movement stats and normalized NDVI, chopped
 % into continuous time sections of a no more than the chosen segment
 % length (eg 1000 hours).  The first half of the data is used for chosing
 % the filter coefficients and the second half is used for evaluating
 % performance.  
 % 
 % E3i8  E10ss12
 % % E13, i 11,18,43  teir 2: i 3,5,8,10,16,25,30,38,40

 % 
 % 
% E13 minX = 37.3041; maxX 37.7115
% minY = 0.4037;   0.7414
 
 clear all;
 K=13;

 
 
names = {'Goya','Maya','Stratus','Ngalatoni','Neptune','Aztec','Maua',...
 'Amina','Ndorobo','Monsoon','Jerusalem','Rosemary','Anastesia'};
 
    M=5; % number of taps to use in Wiener filter
    Q=4; % number of output dimensions to predict
    relw = zeros(9,12); % average relative weights.  in classes x elephants
    ErrT = zeros(K,6); 
    
    
 for E = 13
   load(['E_all3_', num2str(E), '_wiener']); 
    S=length(sys_dat);    [Nt P] = size(sys_dat{1});
    ws = zeros(S,P); val = zeros(1,S);

% initialize some data storage arrays
 pred_mov = []; pred_ndvi = []; pred_stat = []; pred_all = [];
 pred_hum = []; pred_h2o=[]; 
 rel = []; ins = [];  % stack time series together
 Err = zeros(S,6); 

 
 % mse = NaN*ones(S,Q); % reinitialize data array
 for ss= 11% 1:S % loop over sectors 
% ~~~~~~~~Filter using just MOVEMENT input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = sys_dat{ss}(1:N,1:4);
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_mov = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_mov(:,q) = y_mov(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%

% ~~~~~~~~Filter using just COM input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = sys_dat{ss}(1:N,1:2);
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_com = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_com(:,q) = y_com(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%




% ~~~~~~~~Filter using just NDVI input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = sys_dat{ss}(1:N,9:end);% NDVI inputs
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_ndvi = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_ndvi(:,q) = y_ndvi(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%



% ~~~~~~~~Filter using just Static input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = sys_dat{ss}(1:N,[6:8]);
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_stat = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_stat(:,q) = y_stat(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%



% ~~~~~~~~Filter using just HUMAN input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = sys_dat{ss}(1:N,[6,8]);
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_hum = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_hum(:,q) = y_hum(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%




% ~~~~~~~~Filter using just WATER input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = sys_dat{ss}(1:N,7);
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_h2o = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_h2o(:,q) = y_h2o(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%





% ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = sys_dat{ss}(1:N,:);
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_all = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%
for i=1:P % record weights from concatinated signal processing
   ws(ss,i) = mean(mean(abs(W(1+(i-1)*M:i*M,:)),2));
end 
 val(ss) = mean(mean((Y-y_all).^2)); % is it during a massive error?
 
   pred_mov = [pred_mov; y_mov(1:end-M,:)];  % concatinate predictions
    pred_ndvi = [pred_ndvi; y_ndvi(1:end-M,:)];  % concatinate predictions
     pred_stat = [pred_stat; y_stat(1:end-M,:)];  % concatinate predictions
     pred_hum = [pred_hum; y_hum(1:end-M,:)];
     pred_h2o = [pred_h2o; y_h2o(1:end-M,:)];
      pred_all = [pred_all; y_all(1:end-M,:)];  % concatinate predictions
      
   rel = [rel; Y(1:end-M,:)];  
   ins = [ins; X(1:end-M,:)];   

   % Plotting
  %% 
   figure(2), clf; choo = 1:length(y_all); lw=2;
   
   asx = smooth(y_all(choo,1));    asy  = smooth(y_all(choo,2)); 
   msx = smooth(y_mov(choo,1)); msy = smooth(y_mov(choo,2));
   nsx = smooth(y_ndvi(choo,1)); nsy = smooth(y_ndvi(choo,2));
   ssx = smooth(y_stat(choo,1)); ssy = smooth(y_stat(choo,2));
   hsx = smooth(y_h2o(choo,1)); hsy = smooth(y_h2o(choo,2));
   set(gcf,'color','w');    
   
    subplot(4,2,1:4); mt = .2;
   plot(Y(choo,1),Y(choo,2),'k.','LineWidth',lw); hold on;
    plot(asx,asy,'r.','LineWidth',lw);
   xlim([ min(Y(choo,1))-mt*abs(min(Y(choo,1))), max(Y(choo,1))+mt*abs(max(Y(choo,1)))]); 
   ylim([ min(Y(choo,2))-mt*abs(min(Y(choo,2))), max(Y(choo,2))+mt*abs(max(Y(choo,2)))]); 
   % set(gca,'XTickLabels',' ','Xtick',-2,'YTickLabels',' ','Ytick',-2)
       mse_v = mean( mean((y_all(choo,:) - Y(choo,:)).^2,2)./std(Y(choo,:),[],2) ) ;
title(['All predictors, ', '    MSE  ',  num2str(mse_v,3)],'FontSize',15);

       %   title(['All predictors, ', names{E}, '  section ',num2str(ss),  '    MSE  ',  num2str(mse_v,3)],'FontSize',15);


   
   subplot(4,2,5);
   plot(Y(choo,1),Y(choo,2),'k-','LineWidth',lw); hold on;
   plot(msx,msy,'b.','LineWidth',lw);
   xlim([ min(Y(choo,1))-mt*abs(min(Y(choo,1))), max(Y(choo,1))+mt*abs(max(Y(choo,1)))]); 
   ylim([ min(Y(choo,2))-mt*abs(min(Y(choo,2))), max(Y(choo,2))+mt*abs(max(Y(choo,2)))]); 
        mse_v = mean( mean((y_mov(choo,:) - Y(choo,:)).^2,2)./std(Y(choo,:),[],2) ) ;
   title([ 'Past Movement', '    MSE  ',  num2str(mse_v,3)],'FontSize',15);
 %      set(gca,'XTickLabels',' ','Xtick',-2,'YTickLabels',' ','Ytick',-2)

   
   subplot(4,2,6);
   plot(Y(choo,1),Y(choo,2),'k-','LineWidth',lw); hold on;
   plot(nsx,nsy,'g.','LineWidth',lw);
   xlim([ min(Y(choo,1))-mt*abs(min(Y(choo,1))), max(Y(choo,1))+mt*abs(max(Y(choo,1)))]); 
   ylim([ min(Y(choo,2))-mt*abs(min(Y(choo,2))), max(Y(choo,2))+mt*abs(max(Y(choo,2)))]); 
     mse_v = mean( mean((y_ndvi(choo,:) - Y(choo,:)).^2,2)./std(Y(choo,:),[],2) ) ;
   title(['Local NDVI   MSE  ',  num2str(mse_v,3)],'FontSize',15);
  %  set(gca,'XTickLabels',' ','Xtick',-2,'YTickLabels',' ','Ytick',-2)
   
   subplot(4,2,7);
    plot(Y(choo,1),Y(choo,2),'k-','LineWidth',lw); hold on;
    plot(ssx,ssy,'y.','LineWidth',lw);
   xlim([ min(Y(choo,1))-mt*abs(min(Y(choo,1))), max(Y(choo,1))+mt*abs(max(Y(choo,1)))]); 
   ylim([ min(Y(choo,2))-mt*abs(min(Y(choo,2))), max(Y(choo,2))+mt*abs(max(Y(choo,2)))]); 
     mse_v = mean( mean((y_hum(choo,:) - Y(choo,:)).^2,2)./std(Y(choo,:),[],2) ) ;
   title(['Human Features    MSE  ',  num2str(mse_v,3)],'FontSize',15);
 %       set(gca,'XTickLabels',' ','Xtick',-2,'YTickLabels',' ','Ytick',-2)
        
   subplot(4,2,8); 
   plot(Y(choo,1),Y(choo,2),'k-','LineWidth',lw); hold on;
    plot(hsx,hsy,'c.','LineWidth',lw);
   xlim([ min(Y(choo,1))-mt*abs(min(Y(choo,1))), max(Y(choo,1))+mt*abs(max(Y(choo,1)))]); 
   ylim([ min(Y(choo,2))-mt*abs(min(Y(choo,2))), max(Y(choo,2))+mt*abs(max(Y(choo,2)))]); 
   mse_v = mean( mean((y_h2o(choo,:) - Y(choo,:)).^2,2)./std(Y(choo,:),[],2) ) ;
   title(['Perm. Water   MSE ',  num2str(mse_v,3)],'FontSize',15);
  %  set(gca,'XTickLabels',' ','Xtick',-2,'YTickLabels',' ','Ytick',-2)
   %%   GrayScale Version
   figure(2), clf; choo = 1:length(y_all); lw=2;
   
   col = [.5,.5,.5];
   
   asx = smooth(y_all(choo,1));    asy  = smooth(y_all(choo,2)); 
   msx = smooth(y_mov(choo,1)); msy = smooth(y_mov(choo,2));
   nsx = smooth(y_ndvi(choo,1)); nsy = smooth(y_ndvi(choo,2));
   ssx = smooth(y_stat(choo,1)); ssy = smooth(y_stat(choo,2));
   hsx = smooth(y_h2o(choo,1)); hsy = smooth(y_h2o(choo,2));
   set(gcf,'color','w');    
   
   % convert to degrees
   xminv =  min(Y(choo,1))-mt*abs(min(Y(choo,1)));
   xmaxv = max(Y(choo,1))+mt*abs(max(Y(choo,1)));
    yminv = min(Y(choo,2))-mt*abs(min(Y(choo,2)));
    ymaxv = max(Y(choo,2))+mt*abs(max(Y(choo,2)));
   xmi = (xminv+1)/2*(37.7115-37.3041)+37.3041;
   ymi = (yminv+1)/2*(0.7414-0.4037)+0.4037;  
   xma = (xmaxv+1)/2*(37.7115-37.3041)+37.3041;
   yma = (ymaxv+1)/2*(0.7414-0.4037)+0.4037;  
   
   xR = (Y(choo,1)+1)/2*(37.7115-37.3041)+37.3041;
   yR = (Y(choo,2)+1)/2*(0.7414-0.4037)+0.4037;   
   
   xa = (asx+1)/2*(37.7115-37.3041)+37.3041;
   ya = (asy+1)/2*(0.7414-0.4037)+0.4037;   
   
   xm = (msx+1)/2*(37.7115-37.3041)+37.3041;
   ym = (msy+1)/2*(0.7414-0.4037)+0.4037;   
    
     xn = (nsx+1)/2*(37.7115-37.3041)+37.3041;
   yn = (nsy+1)/2*(0.7414-0.4037)+0.4037;  
   
     xs = (ssx+1)/2*(37.7115-37.3041)+37.3041;
   ys = (ssy+1)/2*(0.7414-0.4037)+0.4037;  
   
     xh = (hsx+1)/2*(37.7115-37.3041)+37.3041;
   yh = (hsy+1)/2*(0.7414-0.4037)+0.4037;  
   
    subplot(4,2,1:4); mt = .2;
   plot(xR,yR,'k.','LineWidth',lw); hold on;
    plot(xa,ya,'Marker','.','Color',col,'line','none');
   xlim([xmi, xma]);    ylim([ymi,yma]); 
   % set(gca,'XTickLabels',' ','Xtick',-2,'YTickLabels',' ','Ytick',-2)
       mse_v = mean( mean((y_all(choo,:) - Y(choo,:)).^2,2)./std(Y(choo,:),[],2) ) ;
 %  title(['All predictors, ', names{E}, '  section ',num2str(ss),  '    MSE  ',  num2str(mse_v,3)],'FontSize',15);
title(['All predictors, ', '    MSE  ',  num2str(mse_v,3)],'FontSize',15);
xlabel('Degrees Latitude','FontSize',12); ylabel('Degrees Longitude','FontSize',12);
set(gca,'FontSize',12);

   
   subplot(4,2,5);
   plot(xR,yR,'k-','LineWidth',lw); hold on;
   plot(xm,ym,'Marker','+','Color',col,'line','none');
     xlim([xmi, xma]);    ylim([ymi,yma]); 
     mse_v = mean( mean((y_mov(choo,:) - Y(choo,:)).^2,2)./std(Y(choo,:),[],2) ) ;
   title([ 'Past Movement', '    MSE  ',  num2str(mse_v,3)],'FontSize',15);
      % set(gca,'XTickLabels',' ','Xtick',-2,'YTickLabels',' ','Ytick',-2)
xlabel('Degrees Latitude'); ylabel('Degrees Longitude');
   
   subplot(4,2,6);
   plot(xR,yR,'k-','LineWidth',lw); hold on;
   plot(xn,yn,'Marker','*','Color',col,'line','none');
  xlim([xmi, xma]);    ylim([ymi,yma]); 
     mse_v = mean( mean((y_ndvi(choo,:) - Y(choo,:)).^2,2)./std(Y(choo,:),[],2) ) ;
   title(['Local NDVI   MSE  ',  num2str(mse_v,3)],'FontSize',15);
   % set(gca,'XTickLabels',' ','Xtick',-2,'YTickLabels',' ','Ytick',-2)
  xlabel('Degrees Latitude'); ylabel('Degrees Longitude');
   
   subplot(4,2,7);
    plot(xR,yR,'k-','LineWidth',lw); hold on;
    plot(xs,ys,'Marker','o','Color',col,'line','none');
     xlim([xmi, xma]);    ylim([ymi,yma]); 
     mse_v = mean( mean((y_hum(choo,:) - Y(choo,:)).^2,2)./std(Y(choo,:),[],2) ) ;
   title(['Human Features    MSE  ',  num2str(mse_v,3)],'FontSize',15);
   xlabel('Degrees Latitude'); ylabel('Degrees Longitude');
    %    set(gca,'XTickLabels',' ','Xtick',-2,'YTickLabels',' ','Ytick',-2)
        
   subplot(4,2,8); 
   plot(xR,yR,'k-','LineWidth',lw); hold on;
    plot(xh,yh,'Marker','>','Color',col,'line','none');
    xlim([xmi, xma]);    ylim([ymi,yma]); 
   mse_v = mean( mean((y_h2o(choo,:) - Y(choo,:)).^2,2)./std(Y(choo,:),[],2) ) ;
   title(['Perm. Water   MSE ',  num2str(mse_v,3)],'FontSize',15);
   xlabel('Degrees Latitude'); ylabel('Degrees Longitude');
   % set(gca,'XTickLabels',' ','Xtick',-2,'YTickLabels',' ','Ytick',-2)   %%
   
% figure(1); clf;
% values = {'latitude';'longitude';'dispersion';'orientation'};
    for q = 1:Q;
%        figure(1);% clf;
%         subplot(2,Q/2,q); 
%         %plot(Y(:,q),'k-','Linewidth',3);
%         plot(y_mov(:,q),'g-','LineWidth',.5);
%         hold on;
%         plot(y_stat(:,q),'b-','LineWidth',.5);
%         plot(y_ndvi(:,q),'m-','LineWidth',.5);
%         plot(y_hum(:,q),'y-','LineWidth',.5);
%         plot(y_h2o(:,q),'c','LineWidth',.5);
%          plot(y_all(:,q),'r-','LineWidth',.5);
%         plot(Y(:,q),'k-','LineWidth',.5);
%         title([ 'E',num2str(E),'i',num2str(ss)]);
%         ylim([-1 1]); ylabel(values{q}); xlabel('hours');
%         legend('mov','stat','ndvi','hum','h2o','all','real','Location','Best');
%        % legend('real','all','mov','stat','ndvi','Location','SouthEast');

   E_all(q) = mean( (Y(:,q)-y_all(:,q)).^2)./std(Y(:,q));
   E_mov(q) = mean( (Y(:,q)-y_mov(:,q)).^2)./std(Y(:,q));
   E_stat(q) = mean( (Y(:,q)-y_stat(:,q)).^2)./std(Y(:,q));
   E_hum(q) = mean( (Y(:,q)-y_hum(:,q)).^2)./std(Y(:,q));
   E_h2o(q) = mean( (Y(:,q)-y_h2o(:,q)).^2)./std(Y(:,q));
   E_ndvi(q) = mean( (Y(:,q)-y_ndvi(:,q)).^2)./std(Y(:,q));
    end
 
   rce = 3; % cut-off to detect RCOND singular matrix errors 
    
E_all(E_all>rce) = NaN;    
E_mov(E_mov>rce) = NaN;
E_stat(E_stat>rce) = NaN;
E_hum(E_hum>rce) = NaN;
E_h2o(E_h2o>rce) = NaN;
E_ndvi(E_ndvi>rce) = NaN;


 e_all = nanmean(E_all); e_mov=nanmean(E_mov);  e_ndvi = nanmean(E_ndvi);
e_stat = nanmean(E_stat); e_hum = nanmean(E_hum); e_h2o = nanmean(E_h2o); 
  Err(ss,:) = [e_all, e_mov, e_ndvi, e_stat, e_hum, e_h2o]; 
 
%  text(20,-.5,{[ 'MSE_{all} = ', num2str(e_all,2)]; ['MSE_{mov} = ', num2str(e_mov,2)];
%      ['MSE_{stat} = ', num2str(e_stat,2)]; ['MSE_{ndvi} = ', num2str(e_ndvi,2)];});
pause(10);   
  
end % end loop over sectors 

ErrT(E,:) = nanmean(Err);  

% st = 1024-500; figure(1); clf;
% for q = 1:Q
%        figure(1); 
%         subplot(2,2,q); plot(rel(st+1:st+1000,q),'k-','Linewidth',3);
%         hold on; plot(pred_all(st+1:st+1000,q),'r--');
%         plot(pred_mov(st+1:st+1000,q),'g--');
%         plot(pred_stat(st+1:st+1000,q),'b--');
%         plot(pred_ndvi(st+1:st+1000,q),'m--');
%         title([ 'E',num2str(E),'i',num2str(ss)]);
%         ylim([-1 1]); ylabel('value'); xlabel('hours');
%         legend('real','all','mov','stat','ndvi','Location','Best');
% end

%     % Histograms of error frequencies sorted by different predictors
% err = (pred_all-rel).^2;  err(err>30)=NaN;
% err2 = mean(err'); ws2 = [ws(:,1:8),max(ws(:,9:end)')']; 
% ws3 = ws2./meshgrid(sum(ws2'),1:9)'; % normalize
% 
% % Make the plots
% figure(2); clf; subplot(3,1,1:2); bar(ws3,'stack'); colormap(jet);
% legend('x','y','r','o','season','d2r','d2w', 'd2p', 'ndvi','Location','EastOutside');
% xlabel('time'); ylabel('weights');
% subplot(3,1,3); plot(ins(:,5));  title(['E ',num2str(E)]);
% relw(:,E)= nanmean(ws3);

   clear sys_dat;
pause(5);

 end % end loop over elephants

