    %=================================================================%
    %                        Wiener Filter                            %
    %=================================================================%
 % Alistair Boettiger                                  Date Begun: 03/14/08
 % Getz Lab                                      Functional Since: 04/23/08 
 % Functionally Complete                            Last Modified: 08/21/09
 %
 % Wiener_filter_compsig.m
 %
 % Notes:
 % Wiener Paper Main text: TABLE 1
 % Compare all signals for specific window gaps
 %
 % All 
 % Mov
 % COM only
 %    
 %  
 % Modified 07/24/09 to include Anastesia
 % Modified 07/27/09 to include absolute time data and common space
 % normalization instead of elephant specific spatial normalization.  
 % Modified 08/21/09 to use different MSE measures. (unnormalized and
 % variance normalized)
 %
 %
 % loads data of normalized movement stats and normalized NDVI, chopped
 % into continuous time sections of a no more than the chosen segment
 % length (eg 1000 hours).  The first half of the data is used for chosing
 % the filter coefficients and the second half is used for evaluating
 % performance.  
 % 
 % E3i8  E10ss12
 % 
 
  clear all;
  
  
names = {'Goya','Maya','Stratus','Ngalatoni','Neptune','Aztec','Maua',...
 'Amina','Ndorobo','Monsoon','Jerusalem','Rosemary','Anastesia'};
  
    K=13; % number of pachederms
    M=5; % number of taps to use in Wiener filter
    Q=4; % number of output dimensions to predict
    relw = zeros(9,K); % average relative weights.  in classes x elephants

    ErrT = zeros(K,8); 
    ErrM = zeros(K,8); 
    ErrT2 = zeros(K,8); 
    ErrM2 = zeros(K,8); 
    ErrT3 = zeros(K,8); 
    ErrM3 = zeros(K,8); 
    Err_data = cell(8); 
    
    
 for E= 1:K % 1:K
   load(['E_all3_', num2str(E), '_wiener']); 
    S=length(sys_dat);    [Nt P] = size(sys_dat{1});
    ws = zeros(S,P); val = zeros(1,S);

 Err = zeros(S,8); 
Err2 = zeros(S,8); 
Err3 = zeros(S,8); 

 
 % mse = NaN*ones(S,Q); % reinitialize data array
 for ss= 1:S % loop over sectors 
     % ~~~~~~~~Filter using random input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = rand(N,9);
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_rand = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_rand(:,q) = y_rand(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%
     
     
% ~~~~~~~~Filter using just MOVEMENT input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = sys_dat{ss}(1:N,1:4);
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_mov = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_mov(:,q) = y_mov(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%

% ~~~~~~~~Filter using just COM input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = sys_dat{ss}(1:N,1:2);
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_com = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_com(:,q) = y_com(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%




% ~~~~~~~~Filter using just NDVI input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = sys_dat{ss}(1:N,9:end-1);% NDVI inputs
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_ndvi = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_ndvi(:,q) = y_ndvi(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%



% ~~~~~~~~Filter using just Static input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = sys_dat{ss}(1:N,6:8);
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_stat = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_stat(:,q) = y_stat(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%



% ~~~~~~~~Filter using just HUMAN input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = sys_dat{ss}(1:N,[6,8]);
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_hum = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_hum(:,q) = y_hum(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%




% ~~~~~~~~Filter using just WATER input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = sys_dat{ss}(1:N,7);
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_h2o = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_h2o(:,q) = y_h2o(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%





% ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~%
     % Seperate input and output
        [Nt P] = size(sys_dat{ss});
        N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
        X = sys_dat{ss}(1:N,:);
        Y = sys_dat{ss}(end-N+1:end,1:Q);       
% Initialize some Wiener Filter Parameters
[N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_all = zeros(No,Q);
% =============Start computing autocorrelation matrices================ %
    RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
    for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
          j= 1+floor((i-.2)/P);
          k =1+ mod(i-1,P) ;
         R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
    end
    R_X = cell2mat(R_X); % convert into big matrix. 
          % figure(7); imagesc(R_X); colorbar; 
    for q=1:Q % loop over output dimensions
        R_iy = zeros(P,M);
        for i=1:P % loop over input dimensions
            [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
            R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
        end    
            r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
            W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
        for i=1:P % loop over input dimensions
            y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
            y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
        end       
   end    % end loop over q
% ===================================================================== %
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%
for i=1:P % record weights from concatinated signal processing
   ws(ss,i) = mean(mean(abs(W(1+(i-1)*M:i*M,:)),2));
end 
 val(ss) = mean(mean((Y-y_all).^2)); % is it during a massive error?
 
   
      E_all = zeros(1,Q);
   E_mov = zeros(1,Q);
   E_com = zeros(1,Q);
   E_stat = zeros(1,Q);
   E_hum = zeros(1,Q);
   E_h2o = zeros(1,Q);
   E_ndvi = zeros(1,Q);
   E_rand = zeros(1,Q);

      E_all2 = zeros(1,Q);
   E_mov2 = zeros(1,Q);
   E_com2 = zeros(1,Q);
   E_stat2 = zeros(1,Q);
   E_hum2 = zeros(1,Q);
   E_h2o2 = zeros(1,Q);
   E_ndvi2 = zeros(1,Q);
   E_rand2 = zeros(1,Q);
   
   E_all3 = zeros(1,Q);
   E_mov3 = zeros(1,Q);
   E_com3 = zeros(1,Q);
   E_stat3 = zeros(1,Q);
   E_hum3 = zeros(1,Q);
   E_h2o3 = zeros(1,Q);
   E_ndvi3 = zeros(1,Q);
   E_rand3 = zeros(1,Q);








% values = {'latitude';'longitude';'dispersion';'orientation'};
    for q = 1:Q;
% %        figure(1);% clf;
% %         subplot(2,Q/2,q); 
% %         plot(Y(:,q),'k-','Linewidth',3);
% %         plot(y_mov(:,q),'g-','LineWidth',.5);
% %         hold on;
% %         plot(y_com(:,q),'o-','LineWidth',.5);
% %         plot(y_stat(:,q),'b-','LineWidth',.5);
% %         plot(y_ndvi(:,q),'m-','LineWidth',.5);
% %         plot(y_hum(:,q),'y-','LineWidth',.5);
% %         plot(y_h2o(:,q),'c-','LineWidth',.5);
% %          plot(y_all(:,q),'r-','LineWidth',.5);
% %         plot(Y(:,q),'k-','LineWidth',.5);
% %         title([ 'E',num2str(E),'i',num2str(ss)]);
% %         ylim([-1 1]); ylabel(values{q}); xlabel('hours');
% %         legend('mov','stat','ndvi','hum','h2o','all','real','Location','Best');
       % legend('real','all','mov','stat','ndvi','Location','SouthEast');

   E_all(q) = mean( (Y(:,q)-y_all(:,q)).^2)./std(Y(:,q));
   E_mov(q) = mean( (Y(:,q)-y_mov(:,q)).^2)./std(Y(:,q));
   E_com(q) = mean( (Y(:,q)-y_com(:,q)).^2)./std(Y(:,q));
   E_stat(q) = mean( (Y(:,q)-y_stat(:,q)).^2)./std(Y(:,q));
   E_hum(q) = mean( (Y(:,q)-y_hum(:,q)).^2)./std(Y(:,q));
   E_h2o(q) = mean( (Y(:,q)-y_h2o(:,q)).^2)./std(Y(:,q));
   E_ndvi(q) = mean( (Y(:,q)-y_ndvi(:,q)).^2)./std(Y(:,q));
   E_rand(q) = mean( (Y(:,q)-y_rand(:,q)).^2)./std(Y(:,q));


   E_all2(q) = mean( (Y(:,q)-y_all(:,q)).^2);
   E_mov2(q) = mean( (Y(:,q)-y_mov(:,q)).^2);
   E_com2(q) = mean( (Y(:,q)-y_com(:,q)).^2);
   E_stat2(q) = mean( (Y(:,q)-y_stat(:,q)).^2);
   E_hum2(q) = mean( (Y(:,q)-y_hum(:,q)).^2);
   E_h2o2(q) = mean( (Y(:,q)-y_h2o(:,q)).^2);
   E_ndvi2(q) = mean( (Y(:,q)-y_ndvi(:,q)).^2);
   E_rand2(q) = mean( (Y(:,q)-y_rand(:,q)).^2);
   
   E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./var(Y(:,q));
   E_mov3(q) = mean( (Y(:,q)-y_mov(:,q)).^2)./var(Y(:,q));
   E_com3(q) = mean( (Y(:,q)-y_com(:,q)).^2)./var(Y(:,q));
   E_stat3(q) = mean( (Y(:,q)-y_stat(:,q)).^2)./var(Y(:,q));
   E_hum3(q) = mean( (Y(:,q)-y_hum(:,q)).^2)./var(Y(:,q));
   E_h2o3(q) = mean( (Y(:,q)-y_h2o(:,q)).^2)./var(Y(:,q));
   E_ndvi3(q) = mean( (Y(:,q)-y_ndvi(:,q)).^2)./var(Y(:,q));
   E_rand3(q) = mean( (Y(:,q)-y_rand(:,q)).^2)./var(Y(:,q));


    end
    
%  % Remove errors induced by numerical round-off tolerance
%     rce = 1; % cut-off to detect RCOND singular matrix errors
%  
% E_all2(E_all3>rce) = NaN;   
% E_mov2(E_all3>rce) = NaN;
% E_com2(E_all3>rce) = NaN;
% E_stat2(E_all3>rce) = NaN;
% E_hum2(E_all3>rce) = NaN;
% E_h2o2(E_all3>rce) = NaN; 
% E_ndvi2(E_all3>rce) = NaN;
% E_rand2(E_all3>rce) = NaN;
% 
% 
% E_mov3(E_all3>rce) = NaN;
% E_com3(E_all3>rce) = NaN;
% E_stat3(E_all3>rce) = NaN;
% E_hum3(E_all3>rce) = NaN;
% E_h2o3(E_all3>rce) = NaN; 
% E_ndvi3(E_all3>rce) = NaN;
% E_rand3(E_all3>rce) = NaN;
% E_all3(E_all3>rce) = NaN;   % this must come last or it will change the rest.   


% average errors across prediction values q
 e_all = nanmean(E_all); e_mov=nanmean(E_mov);  e_com = nanmean(E_com); 
 e_ndvi = nanmean(E_ndvi); e_rand = nanmean(E_rand);
 e_stat = nanmean(E_stat); e_hum = nanmean(E_hum); e_h2o = nanmean(E_h2o); 
  Err(ss,:) = [e_all, e_mov,e_com, e_ndvi, e_stat, e_hum, e_h2o,e_rand]; 

 e_all2 = nanmean(E_all2); e_mov2=nanmean(E_mov2);  e_com2 = nanmean(E_com2); 
 e_ndvi2 = nanmean(E_ndvi2); e_rand2 = nanmean(E_rand2);
 e_stat2 = nanmean(E_stat2); e_hum2 = nanmean(E_hum2); e_h2o2 = nanmean(E_h2o2); 
  Err2(ss,:) = [e_all2, e_mov2,e_com2, e_ndvi2, e_stat2, e_hum2, e_h2o2,e_rand2]; 

   e_all3 = nanmean(E_all3); e_mov3 = nanmean(E_mov3);  e_com3 = nanmean(E_com3); 
 e_ndvi3 = nanmean(E_ndvi3); e_rand3 = nanmean(E_rand3);
 e_stat3 = nanmean(E_stat3); e_hum3 = nanmean(E_hum3); e_h2o3 = nanmean(E_h2o3); 
  Err3(ss,:) = [e_all3, e_mov3,e_com3, e_ndvi3, e_stat3, e_hum3, e_h2o3,e_rand3]; 
 
  
end % end loop over sectors 

Err_data{E} = Err; 
ErrT(E,:) = nanmean(Err);
ErrM(E,:) = nanmedian(Err); 
ErrT2(E,:) = nanmean(Err2);  
ErrM2(E,:) = nanmedian(Err2);
ErrT3(E,:) = nanmean(Err3);  
ErrM3(E,:) = nanmedian(Err3);
 clear sys_dat;
 end % end loop over elephants

 median(Err3(Err3(:,1)<1))
 % save compsig_data2 ErrT ErrM ErrT2 ErrM2 ErrT3 ErrM3 Err_data; 
 
 %%
 clear all;  load compsig_data2; 
 


bar1 = Err_data(1:13); bar2 = cell2mat(bar1');

C1 = [[0,0,1];
      [0,1,0];
      [1,0,.5]];
    
for k=1:13
    Anna = bar1{k};
%     figure(3); clf; bar(Anna(:,[1,2,4,5])) ;  ylim([0,5]);
%     legend('all','mov','ndvi','static');

    iAnna = 1./Anna; 
    figure(3); clf; bar(iAnna(:,[2,4,5]),'stack') ; 
    legend('mov','ndvi','static');  colormap(C1);
    set(gcf,'color','w'); 
    set(gca,'FontSize',18);  xlim([0,55]);

    iAnna2 = iAnna(:,[2,4,5]);
    [T,v] = size(Anna);

    for i=1:T; 
    iAnna2(i,:) = iAnna2(i,:)/sum(iAnna2(i,:));
    end

    figure(4); clf; bar(iAnna2,'stack') ; 
    legend('mov','ndvi','static','Location','EastOutside');  colormap(C1);
    set(gcf,'color','w'); set(gca,'FontSize',18); ylim([0,1]); xlim([0,55]);

    pause(3);
end


dpts = length(ErrM);
C = [0,2,2,1,3,3,3];
colordef white; figure(1); set(gcf,'color','w'); 
xlabels = {'All factors','Past mov.','CoM mov.','NDVI','Static','Human','Water'};
figure(1); clf; boxplot(ErrM(:,1:7),'plotstyle','compact','labels',xlabels,'colorgroup',C,'colors','rgbm','labelorientation','inline');
ylim([0,.7]);


   

   figure(2); clf; 
   xlabels = {'All factors','Past mov.','NDVI','Static Feat.','Null Model'};
set(gca,'Xtick',1:4,'XTickLabel',xlabels,'FontSize',15);
   h = boxplot([ErrM(:,[1,2,4,5])],'notch','on','labelorientation','inline');
   set(gca,'Xtick',1:4,'XTickLabel',xlabels,'FontSize',14);
 ylim([0,.5]); ylabel('Normalized MSE');

   hText = xticklabel_rotate90(1.35:5.35,xlabels,30,1);
   set(hText,'FontSize',12); 
   set(hText,'VerticalAlignment','baseline');
   set(gcf,'color','w'); ylabel('normalized MSE','FontSize',12); 
   set(gca,'fontsize',12);


Q1 = zeros(1,8); Q3 = zeros(1,8);
for i=1:8,
    vals = sort(ErrM(:,i));
    qpts = round(dpts/4);
    ind1 = find(vals>0,qpts,'first');
    ind3 = find(vals>0,qpts,'last');
    Q1(i) = vals(ind1(qpts));
    Q3(i) = vals(ind3(1));
end

    
    

 