    %=================================================================%
    %                        Wiener Filter                            %
    %=================================================================%
 % Alistair Boettiger                                  Date Begun: 03/14/08
 % Getz Lab                                      Functional Since: 07/18/09 
 % Functionally Complete                            Last Modified: 01/06/10
 %
 % Wiener_filter_err_locations.m
 %
 % Notes:
 % Wiener Paper Main text FIGURE:
 % Find spatial locations where error is greatest
 %
 %  Modified 07/31/09 to encorperate Anastesia and remove extraneous code.
 %  And improve annotation
 %
 % loads data of normalized movement stats and normalized NDVI, chopped
 % into continuous time sections of a no more than the chosen segment
 % length (eg 1000 hours).  The first half of the data is used for chosing
 % the filter coefficients and the second half is used for evaluating
 % performance.  
 % 
 %
 %  
 %
 % This code uses data:
 %  real_pos_data.mat 
 %  * stat_data_good.mat   -- locations of rivers, parks and roads in degrees 
 %  * e_stats4.mat  -- locations of all 13 elephants, in degrees
 %  * E_all3_N_wiener.mat, with N from 1:13  -- 1000 hr segmented data for
 %       filtering analysis 
 %  * 

 clear all; 
 lat_pts=100;
 long_pts=100;
% load real_pos_data; 
load e_stats4 xcm ycm;
load stat_data_good; % rivers, parks and roads locations 

Names = {'Goya','Maya','Stratus','Ngalatoni','Neptune','Aztec','Maua',...
'Amina','Ndorobo','Monsoon','Jerusalem','Rosemary','Anastasia'};

K = length(Names); NED = cell(1,K); posi = zeros(K,4); 
NEK = cell(K); 

villages = [.60,37.42; .65,37.48; .545,37.49; .650,37.67; .50,37.66];

C = jet(3000); 
C = [zeros(300,3);C];

frac_out = zeros(K,1); 
p_sig = zeros(K,1);
err_stat = zeros(K,2); 
cor = cell(1,K); 
% err_sum = cell(1,12); 


%~~~~~ Set up superposition map ~~~~~~~~~~~~%

% Get appropriate scale factors to superimpose real maps with errror map
% Initiatlize data arrays with the scale sizes.  
     x = xcm;   % x-size / longitude points
    x(x==0) = NaN;
    xmin = nanmin(nanmin(x));
    xmax = nanmax(nanmax(x));
       
    y = ycm; % y-size / latitude points
    y(y==0) = NaN;
    ymin = nanmin(nanmin(y));
    ymax = nanmax(nanmax(y)); 

    % X, Y arrays for 3D/color plotting
    longs = linspace(xmin,xmax,long_pts);
    lats = linspace(ymin,ymax,lat_pts);
    [Long,Lat] = meshgrid(longs,lats); 
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%   

    M=5; % number of taps to use in Wiener filter
    Q=4; % number of output dimensions to predict
    relw = zeros(9,12); % average relative weights.  in classes x elephants
    NT = zeros(lat_pts,long_pts); 
    % NT = zeros(size(A));
    WT = NT; ET = NT; 
    NT2 = NT;

   
    
    
    
     figure(1); clf; figure(2); clf;
 for E= 1:K % loop over elephants
    %  figure(2); clf;
   load(['E_all3_', num2str(E), '_wiener']); 
   % E_all2 use data on elephant specific coordinates. 
   % E_all3 use data on general coordinates
    S=length(sys_dat);    [Nt P] = size(sys_dat{1});
    ws = zeros(S,P); val = zeros(1,S);

% initialize some data storage arrays
err_pos = cell(1,S); 




 err = cell(1,S); ra =cell(1,S);   % test values
 cor{E} = zeros(1,S);
    
    % iniatlize error and posistion density arrays
    EC = zeros(lat_pts,long_pts);
    WC = zeros(lat_pts,long_pts);
 
 % Weiner Filter Code
 for ss=1:S % loop over sectors  
    % ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~%
         % Seperate input and output
            [Nt P] = size(sys_dat{ss});
            N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
            X = sys_dat{ss}(1:N,:);
            Y = sys_dat{ss}(end-N+1:end,1:Q);       
    % Initialize some Wiener Filter Parameters
    [N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_all = zeros(No,Q);
    % =============Start computing autocorrelation matrices================ %
        RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
        for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
              j= 1+floor((i-.2)/P);
              k =1+ mod(i-1,P) ;
             R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
        end
        R_X = cell2mat(R_X); % convert into big matrix. 
              % figure(7); imagesc(R_X); colorbar; 
        for q=1:Q % loop over output dimensions
            R_iy = zeros(P,M);
            for i=1:P % loop over input dimensions
                [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
                R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
            end    
                r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
                W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
            for i=1:P % loop over input dimensions
                y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
                y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
            end       
       end    % end loop over q
    % ===================================================================== %
    %~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%

     err_loc = mean((Y-y_all).^2,2) ./ std(mean(Y,2)) > 1.5;% 2.7; % 1.5; %  1.5; 1.75
     x_errs = Y(err_loc,1);
     y_errs = Y(err_loc,2);
     
     err_pos{ss} = [x_errs,y_errs];  

     
% % Search for other correlations between error and input or output values
     % r_errs = [r_errs; Y(err_loc,3)]; 
     errtemp =  mean((Y-y_all).^2,2) ./ std(mean(Y,2));
     errtemp(errtemp>1.75) = 2; 
     err{ss} = errtemp; 
     
     ra{ss} = Y(:,3); 
     season = X(:,5); 
     % season_errs = X(err_loc,5);
     
     R = corrcoef(err{ss},ra{ss});
       % R = corrcoef(err{ss},season);
     cor{E}(ss) = R(2,1); 
     
%      figure(1); clf; plot(ra{ss},err{ss},'k.'); 
%      title(['correlation   ', num2str( cor{E}(ss) )]);
%      pause(.1); 
     
     

     
   % % Trouble shooting plot: plot trajectory, highlight points where large
   % %        errors were made.    
    %  figure(2); hold on; xlim([-1,1]); ylim([-1,1]); 
    %  plot(Y(:,1),Y(:,2),'k.'); hold on;
    %  scatter(x_errs,y_errs);
% % **fraction of errors in vs. outside park code at end.  

    Err = vect2density(x_errs,y_errs,long_pts,lat_pts); % custom function
    Walk = vect2density(Y(:,1),Y(:,2),long_pts,lat_pts);
    EC = EC + Err;
    WC = WC + Walk; 
end % end loop over sectors 


clear sys_dat;

% Compute fraction of error regions which occur inside and outside
   NE = EC./WC;   NE(isnan(NE)) = 0; 
   D = false(size(NE)); % initialize a logical array of zeros
  % D(NE>.2) = 1;  % cutoff mean error fraction (20% of time)
   %                 to be considered as an 'error region'
   xps = Long(D);     yps = Lat(D);
   err_in = inpolygon(xps,yps,parks_x(1281:end),parks_y(1281:end));
   tot_errs = length(xps);  % total number of error sectors
   errsin = sum(err_in); % number of error sectors inside park boundary
  
   % fraction of error sectors outside park boundary
  frac_out(E) = (length(xps)-sum(err_in)) / length(xps); 
  err_stat(E,:) = [errsin,tot_errs]; % store errors in and total errors

  % statistical signficance compared to binomial 50 50 probability of
  % errors occuring inside or outside.  Null hypothesis is 50:50
p_sig(E) = 1-binocdf((length(xps)-sum(err_in)), length(xps)+1,.5) ;
  
    
  

 vst = .001*WC./WC; vst(isnan(vst))=0;
 NE = NE+vst; 
 

 C = jet(5000); 
C = [zeros(1,3);C];
  figure(1);  subplot(4,4,E); colormap(C);
 NE(WC==0)=-.0001;
     pcolor(Long,Lat,NE); shading interp;
     hold on;  
  plot(roads_x,roads_y,'m'); hold on;
  plot(rivs_x,rivs_y,'c'); 
  plot(parks_x,parks_y,'g');
   plot(villages(:,2),villages(:,1),'ro','MarkerSize',5,'linewidth',1);
xlabel('degrees E longitude');  ylabel('degrees N latitude');
title(Names{E});
 ylim([.45,.8]); xlim([37.3,37.95]);

 NEK{E} = NE;

  figure(11);  subplot(4,4,E); colormap(C);
   colordef white; set(gcf,'color','w'); 
 NE(WC==0)=-.0001;
     pcolor(Long,Lat,NE); shading interp;
     hold on;  
      ylim([.45,.8]); xlim([37.3,37.95]);
      axis off; 
      
figure(12); subplot(4,4,E); 
 colordef white; set(gcf,'color','w'); 
  plot(roads_x,roads_y,'m'); hold on;
  plot(rivs_x,rivs_y,'c'); 
  plot(parks_x,parks_y,'g');
   plot(villages(:,2),villages(:,1),'ro','MarkerSize',5,'linewidth',1);
xlabel('degrees E longitude');  ylabel('degrees N latitude');
title(Names{E});
 ylim([.45,.8]); xlim([37.3,37.95]);


 figure(2);  subplot(4,4,E); colormap(C); 
     pcolor(Long,Lat,WC); shading interp;
     hold on;  
  plot(roads_x,roads_y,'m'); hold on;
  plot(rivs_x,rivs_y,'c'); 
  plot(parks_x,parks_y,'g');
    plot(villages(:,2),villages(:,1),'ro','MarkerSize',5,'linewidth',1);
xlabel('degrees E longitude');  ylabel('degrees N latitude');
title(Names{E});
%  

  %  NT = NT + NE;
    NT2 = nanmax(NT2,NE);   % max project
    NT = nanmax(NT, NE/max(max(NE))); % 
    WT = WT + WC;  

   % figure(3); clf; pcolor(long2,lat2,NT); shading interp;
end % end loop over elephants



%  N2 = NT;
%  N2(NT<.1*max(max(NT))) = 0; 
%  N2(N2>0) = N2(N2>0) + 1*max(max(NT)); 
%  Err_map = 1*A*max(max(NT)) + N2;
%  C1 = hot(100);
%  C2 = cool(100);
%  C3 = [C1;C2];
% figure(3); clf; 
% pcolor(long2,lat2,Err_map); shading interp; colormap(C3); 
% colorbar; hold on;  % figure(5);
%   plot(roads_x,roads_y,'y'); hold on;
%   plot(rivs_x,rivs_y,'b'); 
%   plot(parks_x,parks_y,'r');
% xlabel('degrees E longitude');  ylabel('degrees N latitude');


% save spatialerr_1p5


NT(WT==0)=-.0001;
figure(5); clf; pcolor(longs,lats,WT); shading interp;
colormap(C); colorbar; hold on;  % figure(5);
  plot(roads_x,roads_y,'y','linewidth',1); hold on;
  plot(rivs_x,rivs_y,'c','linewidth',1); 
  plot(parks_x,parks_y,'r','linewidth',2);
  xlabel('degrees E longitude');  ylabel('degrees N latitude');


NT2(WT==0)=-.1;  colordef black;
fig6 = figure(6); clf;
axes1 = axes('Parent',fig6);
pcolor(longs,lats,NT2); shading interp;  hold on; 
colormap(C);  colorbar;  % figure(5); 
  plot(roads_x,roads_y,'m','linewidth',1); hold on;
  plot(rivs_x,rivs_y,'c','linewidth',1); 
  plot(parks_x,parks_y,'g','linewidth',2);
  plot(villages(:,2),villages(:,1),'ro','MarkerSize',30,'linewidth',3);
  
 xlabel('degrees E longitude', 'FontSize',18);
 ylabel('degrees N latitude','FontSize',18);
 set(gcf,'color','white'); set(gca,'FontSize',18);
 colorbar('peer',axes1,'YTickLabel',{'No data','Low','','','','High',''},...
    'YTick',[-.1:.2:1],'FontSize',18);
 ylim([.45,.8]); xlim([37.3,37.95]);
 
 set(gcf,'color','k');
 set(gca,'color','w');



mcor = zeros(1,E);
 for E=1:K
     mcor(E) = nanmean(cor{E});
 end

% save spatial_err_dat;
 
%------- Appendices / Supplemental Code


%  

% %~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%
    


% %:::::: fraction of errors in park vs fraction out of park

%  % This goes outside sectors loop        
%        % error statistics 
%         err_inp = ones(S,1); 
%         err_out= ones(S,1); 
%         npts_inT = 0;
%         epts_inT = 0;
%         npts_outT = 0;
%         epts_outT = 0; 
%          % err_in_f = ones(S,1); 
      

% % =================================================================== %
% %            Old Error Location Statistical Analysis                  %
% % =================================================================== %
% % Transform errors into coordinate system to plot overaid with park boundaries
%     xe =  (xmin+(1+x_errs)/2*(xmax-xmin));
%     ye =  (ymin+(1+y_errs)/2*(ymax-ymin));
% % Transform x,y positions into coordinates to plot overlaid with park boundaries
%     x_in =  (xmin+(1+Y(:,1))/2*(xmax-xmin));
%     y_in =  (ymin+(1+Y(:,2))/2*(ymax-ymin)); 
%  % Compute if errors / points are inside park boundaries
%     err_in = inpolygon( xe,ye,parks_x(1281:end),parks_y(1281:end));
%     pt_in = inpolygon(x_in,y_in,parks_x(1281:end),parks_y(1281:end));
% 
% 
% % Plot trajectories, flagging in and out of park and in and out errors
% %        separately.  
%     %  figure(4); clf;  hold on; plot(parks_x(1281:end),parks_y(1281:end),'r-');
%     %  plot(x_in,y_in,'k.'); plot(x_in(pt_in),y_in(pt_in),'ro');
%     %  plot(xe,ye,'g.'); plot(xe(err_in),ye(err_in),'bo');
%
%  %~~~~~~%~~~~~~~% Compute total number of error points  %~~~~~~~%~~~~~~%
%     % x_in(logical(1-pt_in));  y_in(logical(1-pt_in)); % pts outside park
%     npts_in = sum(pt_in);  % number of points in the park
%     nerrs_in = sum(err_in); % number of errors in the park 
% 
%     npts_out = length(x_in) - sum(pt_in); % number of pts outside the park
%     nerrs_out = length(xe) - sum(err_in); % number of errors outside the park;
% 
%     % if there are no points in (out) of the park the error in (out) of the park is zero 
%     if npts_in == 0; 
%         err_inp(ss) = 0;
%     else
%        err_inp(ss) = nerrs_in./npts_in; 
%     end
%     if npts_out == 0; 
%         err_out(ss) = 0;
%     else
%         err_out(ss) = nerrs_out./npts_out;  
%     end
% 
%     npts_inT = npts_inT + npts_in;
%     epts_inT = epts_inT + nerrs_in;
%     npts_outT = npts_outT + npts_out;
%     epts_outT = epts_outT + nerrs_out; 
%   %~~~~~~~%~~~~~~%~~~~~~~%~~~~~~%~~~~~~~%~~~~~~%~~~~~~~%~~~~~%~~~~~~~%
% %======================================================================% 




%

%

%

% xcm(xcm == 0) = nan; 
% ycm(ycm ==0) = nan;
% minTx =  nanmin(nanmin(xcm)) ; % this is just below the elev map cutoff 37
% maxTx = nanmax(nanmax(xcm))-37; % counting from min long of 37 for elev map
% minTy = nanmin(nanmin(ycm)); % furtherest
% maxTy = nanmax(nanmax(ycm)); % 
% 
% 
% fn = '/Users/alistair/Documents/Berkeley/Getz Lab/Elevation.tiff';
% I = double(imread(fn));
% I = I/255;
%     minlong = 37; maxlong = 39;
%     minlat = 0; maxlat = 1;
%     Elong = linspace(minlong,maxlong,(maxlong-minlong)*1250);
%     Elat = linspace(minlat,maxlat,(maxlat-minlat)*1250); 
%     % No rescaling conversion 
%     long2 = Elong(1:round(maxTx*1250));
%     lat2 = Elat(round(minTy*1250):end);
%     A = I(round(minTy*1250):end,1:round(maxTx*1250));
% 
% rescale map by down sampling elevation positions
% stp = 20; 
% long2 = Elong(1:stp:round(maxTx*1250));
% lat2 = Elat(round(minTy*1250):stp:end);
% A = I(round(minTy*1250):stp:end,1:stp:round(maxTx*1250));
%     figure(11); clf; pcolor(long2,lat2,A); shading flat; colormap(copper);
%     figure(10); clf; pcolor(Elong,Elat,I); shading flat;

