    %=================================================================%
    %                        Wiener Filter                            %
    %=================================================================%
 % Alistair Boettiger                                  Date Begun: 03/14/08
 % Getz Lab                                      Functional Since: 04/23/08 
 % Functionally Complete                            Last Modified: 11/04/09
 %
 % Wiener_filter_generalize_v5.m
 %
 % Notes:
 % updated 10/28 to automatically do all temporal, seasonal, and spatial
 % restrictions, and to create box plots of the results.
 % Attempt to use filters created for one data set to predict entirely different data sets; 
 %  E_all2_ has 13 elephants, space normalized to the domain of each elephant  
 %  E_all3_ has space normalized to the max domains of all elephants
 
  clear all;
    K = 13;
    M=5; % number of taps to use in Wiener filter
    Q=4; % number of output dimensions to predict
   Err = zeros(K,2); 
  
     W_allE = cell(K,1);
   
 for E=1:K
   load(['E_all4_', num2str(E), '_wiener']); 
    S=length(sys_dat);    [Nt P] = size(sys_dat{1});
  
 e_all = zeros(1,S); W_all = cell(S,1); 

          % mse = NaN*ones(S,Q); % reinitialize data array
     for ss= 1:S % loop over sectors 

    %  ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~%
         % Seperate input and output
            [Nt P] = size(sys_dat{ss});
            N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
            X = sys_dat{ss}(1:N,:);
            Y = sys_dat{ss}(end-N+1:end,1:Q);       
    % Initialize some Wiener Filter Parameters
    [N,P]=size(X); [No,Q]=size(Y); W=zeros(M*P,Q); y_all = zeros(No,Q);
    % =============Start computing autocorrelation matrices================ %
        RX = xcorr(X,N/2,'unbiased'); R_X = {}; % compute correlation functions
        for i=1:P^2 % stack correlation functions into block Toeplitz corr. matrices 
              j= 1+floor((i-.2)/P);
              k =1+ mod(i-1,P) ;
             R_X{j,k} = toeplitz(RX(N/2+1:N/2+M,i));
        end
        R_X = cell2mat(R_X); % convert into big matrix. 
              % figure(7); imagesc(R_X); colorbar; 
        for q=1:Q % loop over output dimensions
            R_iy = zeros(P,M);
            for i=1:P % loop over input dimensions
                [c_iy, lags] = xcorr(X(1:No,i),Y(:,q),No/2,'unbiased') ;
                R_iy(i,:) = flipud(c_iy(No/2+2:No/2+M+1));
            end    
                r_iy = reshape(R_iy',P*M,1)'; % cross correlation fxn
                W(:,q) =  (r_iy/R_X)';  % compute Weiner Filter Coefficients
            for i=1:P % loop over input dimensions
                y_t = conv(X(1:No,i),W(1+(i-1)*M:i*M,q));
                y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
            end       
       end    % end loop over q
    % ===================================================================== %
    W_all{ss} = W; 
    %~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%
       for q = 1:Q;
           E_all(q) = mean( (Y(:,q)-y_all(:,q)).^2)./std(Y(:,q));
       end
       
     e_all(ss) = nanmean(E_all); 
    end % end second loop over sector

W_allE{E} = W_all; 







% Shift all filters by 1  %4 not too bad
    e_all2 = zeros(1,S);
    for ss = 11:S
    % ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~ %
         % Seperate input and output
            [Nt P] = size(sys_dat{ss});
            N = 2*floor(floor(Nt/2)/2); %split data set in half. N must be even
            X = sys_dat{ss}(1:N,:);
            Y = sys_dat{ss}(end-N+1:end,1:Q);       
    % Initialize some Wiener Filter Parameters
    [N,P]=size(X); [No,Q]=size(Y); y_all = zeros(No,Q);

    shift = round(rand*10);
    
        for q=1:Q % loop over output dimensions
            for i=1:P % loop over input dimensions
                y_t = conv(X(1:No,i),W_allE{E}{ss-shift}(1+(i-1)*M:i*M,q));  % use archived filter from previous time points
                y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
            end       
       end    % end loop over q
    % ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ %
       for q = 1:Q;
           E_all2(q) = mean( (Y(:,q)-y_all(:,q)).^2)./std(Y(:,q));
       end
     e_all2(ss) = mean(E_all2); 
    end % end second loop over sector
   Err(E,:) =[nanmedian(e_all), nanmedian(e_all2)]; 

 clear sys_dat;
 end % end loop over elephants


 %% Compare Across Elephants and Across Times
 Q=2; K=13;
 Sdepth = zeros(K,K,10);  % sampling depth
 ErrE = zeros(K,K,10); 
 
 
 
for EE=1:K
     for E=1:K
         E
 % Shift all filters by 1  %4 not too bad
       load(['E_all3_', num2str(EE), '_wiener']); 
        Ea = sys_dat; clear sys_dat;
       Sa=length(Ea);    [Nt P] = size(Ea{1});
      load(['E_all3_', num2str(E), '_wiener']); 
      Eb = sys_dat; clear sys_dat;
        Sb = length(Eb);
          
    jt = 0; jn = 0; js = 0; jp = 0; jts = 0; jtp = 0; jps =0; jtps=0; 
    jg = 0 ; jga =0; 
          
 et = []; % different elephant, within +/- 3 months time
 en = []; % no restriction
 es = []; % different elephant, within 20 % season 
 ep = [];% different elephant, 20 % position
 ets = [];% different elephant, within +/- 3 months time and 20% season
 etp = [];% different elephant, within +/- 3 months time and 20% position
 eps = [];% different elephant, within 20% season and 20% position
 etps = [];%  within +/- 3 months time, 20% postion, 20% season
 eg = []; % greater than 3 months
 ega =[]; % greater than 3 months away
          

          
        for ssa=1:Sa;
            for ssb=1:Sb % loop through all possible section pairs
               % sdist =  Ea{ssa}(5) - Eb{ssb}(5); % distance in timing
                sdist =  Ea{ssa}(1,5) - Eb{ssb}(1,5); % distance in season
                tdist =   Ea{ssa}(1,17) - Eb{ssb}(1,17);
                pdist = sqrt( (Ea{ssa}(1,1)-Eb{ssb}(1,1)).^2 + (Ea{ssa}(1,2)-Eb{ssb}(1,2)).^2);   
                 [Nta P] = size(Ea{ssa});
                 [Ntb P] = size(Eb{ssb});
                    
                 
                   sameEsameT = (EE == E && ssa == ssb);

                   
         %@@@@@@@@@@@@@@@@@@@@@@@@@@@
         %   No Restrictions
         %@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
             if  ( Nta==Ntb && ~sameEsameT ) %  abs(tdist) < .1 && 
                %   if ~sameEsameT 
                    % similar time, same size data set, similar location
                    jn = jn+1;
                     [EE,E,ssa,ssb];  % print coordinates of overlap
                % ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~ %
                     % Seperate input and output
                       
                        N = 2*floor(floor(Nta/2)/2); %split data set in half. N must be even
                        X = Ea{ssa}(1:N,1:end-1);
                        Y = Ea{ssa}(end-N+1:end,1:Q);       
                  % Initialize some Wiener Filter Parameters
                  [N,P]=size(X); [No,Q]=size(Y); y_all = zeros(No,Q);
                    for q=1:Q % loop over output dimensions
                        for i=1:P % loop over input dimensions
                            y_t = conv(X(1:No,i),W_allE{E}{ssb}(1+(i-1)*M:i*M,q));  % use archived filter from other elephant
                            y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
                        end       
                   end    % end loop over q
                % ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ %
                   for q = 1:2;
                      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./std(Y(:,q));
                    %      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./var(Y(:,q));
                   end
                   en(jn) = mean(E_all3);                  
             end
           %@@@@@@@@@@@@@@@@@@@@@@@@@@@
                   
        
          %@@@@@@@@@@@@@@@@@@@@@@@@@@@
             %   tdist < .04
         %@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
             if  (  abs(tdist) < .04 && Nta==Ntb && ~sameEsameT ) %  abs(tdist) < .1 && 
                %   if ~sameEsameT 
                    % similar time, same size data set, similar location
                    jt = jt+1;
                    % [EE,E,ssa,ssb]  % print coordinates of overlap
                % ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~ %
                     % Seperate input and output
                       
                        N = 2*floor(floor(Nta/2)/2); %split data set in half. N must be even
                        X = Ea{ssa}(1:N,1:end-1);
                        Y = Ea{ssa}(end-N+1:end,1:Q);       
                  % Initialize some Wiener Filter Parameters
                  [N,P]=size(X); [No,Q]=size(Y); y_all = zeros(No,Q);
                    for q=1:Q % loop over output dimensions
                        for i=1:P % loop over input dimensions
                            y_t = conv(X(1:No,i),W_allE{E}{ssb}(1+(i-1)*M:i*M,q));  % use archived filter from other elephant
                            y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
                        end       
                   end    % end loop over q
                % ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ %
                   for q = 1:2;
                      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./std(Y(:,q));
                    %      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./var(Y(:,q));
                   end
                   et(jt) = mean(E_all3);                  
             end
           %@@@@@@@@@@@@@@@@@@@@@@@@@@@
             
           
            %@@@@@@@@@@@@@@@@@@@@@@@@@@@
             %   tdist > .04
         %@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
             if  (  abs(tdist) > .04 && Nta==Ntb && ~sameEsameT ) %  abs(tdist) < .1 && 
                %   if ~sameEsameT 
                    % similar time, same size data set, similar location
                    jg = jg+1;
                    % [EE,E,ssa,ssb]  % print coordinates of overlap
                % ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~ %
                     % Seperate input and output
                       
                        N = 2*floor(floor(Nta/2)/2); %split data set in half. N must be even
                        X = Ea{ssa}(1:N,1:end-1);
                        Y = Ea{ssa}(end-N+1:end,1:Q);       
                  % Initialize some Wiener Filter Parameters
                  [N,P]=size(X); [No,Q]=size(Y); y_all = zeros(No,Q);
                    for q=1:Q % loop over output dimensions
                        for i=1:P % loop over input dimensions
                            y_t = conv(X(1:No,i),W_allE{E}{ssb}(1+(i-1)*M:i*M,q));  % use archived filter from other elephant
                            y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
                        end       
                   end    % end loop over q
                % ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ %
                   for q = 1:2;
                      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./std(Y(:,q));
                    %      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./var(Y(:,q));
                   end
                   eg(jg) = mean(E_all3);                  
             end
           %@@@@@@@@@@@@@@@@@@@@@@@@@@@
           
           
                
            %@@@@@@@@@@@@@@@@@@@@@@@@@@@
             %   tdist > .04 and all other restrictions
         %@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
             if  (  abs(tdist) > .04 && abs(pdist)<.2 && abs(sdist)<.2 && Nta==Ntb && ~sameEsameT ) %  abs(tdist) < .1 && 
                %   if ~sameEsameT 
                    % similar time, same size data set, similar location
                    jga = jga+1;
                    % [EE,E,ssa,ssb]  % print coordinates of overlap
                % ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~ %
                     % Seperate input and output
                       
                        N = 2*floor(floor(Nta/2)/2); %split data set in half. N must be even
                        X = Ea{ssa}(1:N,1:end-1);
                        Y = Ea{ssa}(end-N+1:end,1:Q);       
                  % Initialize some Wiener Filter Parameters
                  [N,P]=size(X); [No,Q]=size(Y); y_all = zeros(No,Q);
                    for q=1:Q % loop over output dimensions
                        for i=1:P % loop over input dimensions
                            y_t = conv(X(1:No,i),W_allE{E}{ssb}(1+(i-1)*M:i*M,q));  % use archived filter from other elephant
                            y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
                        end       
                   end    % end loop over q
                % ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ %
                   for q = 1:2;
                      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./std(Y(:,q));
                    %      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./var(Y(:,q));
                   end
                   ega(jga) = mean(E_all3);                  
             end
           %@@@@@@@@@@@@@@@@@@@@@@@@@@@
           
             
           %@@@@@@@@@@@@@@@@@@@@@@@@@@@@
             if  (  abs(pdist) < .2 && Nta==Ntb && ~sameEsameT ) %  abs(tdist) < .1 && 
                %   if ~sameEsameT 
                    % similar time, same size data set, similar location
                    jp = jp+1;
                     % [EE,E,ssa,ssb]  % print coordinates of overlap
                % ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~ %
                     % Seperate input and output
                       
                        N = 2*floor(floor(Nta/2)/2); %split data set in half. N must be even
                        X = Ea{ssa}(1:N,1:end-1);
                        Y = Ea{ssa}(end-N+1:end,1:Q);       
                  % Initialize some Wiener Filter Parameters
                  [N,P]=size(X); [No,Q]=size(Y); y_all = zeros(No,Q);
                    for q=1:Q % loop over output dimensions
                        for i=1:P % loop over input dimensions
                            y_t = conv(X(1:No,i),W_allE{E}{ssb}(1+(i-1)*M:i*M,q));  % use archived filter from other elephant
                            y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
                        end       
                   end    % end loop over q
                % ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ %
                   for q = 1:2;
                      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./std(Y(:,q));
                    %      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./var(Y(:,q));
                   end
                   ep(jp) = mean(E_all3);                  
             end
          %@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@      
                 
                 
         %@@@@@@@@@@@@@@@@@@@@@@@@@@@
             if  (  abs(sdist) < .2 && Nta==Ntb && ~sameEsameT ) % 
                %   if ~sameEsameT 
                    % similar time, same size data set, similar location
                    js = js+1;
                     % [EE,E,ssa,ssb]  % print coordinates of overlap
                % ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~ %
                     % Seperate input and output
                       
                        N = 2*floor(floor(Nta/2)/2); %split data set in half. N must be even
                        X = Ea{ssa}(1:N,1:end-1);
                        Y = Ea{ssa}(end-N+1:end,1:Q);       
                  % Initialize some Wiener Filter Parameters
                  [N,P]=size(X); [No,Q]=size(Y); y_all = zeros(No,Q);
                    for q=1:Q % loop over output dimensions
                        for i=1:P % loop over input dimensions
                            y_t = conv(X(1:No,i),W_allE{E}{ssb}(1+(i-1)*M:i*M,q));  % use archived filter from other elephant
                            y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
                        end       
                   end    % end loop over q
                % ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ %
                   for q = 1:2;
                      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./std(Y(:,q));
                    %      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./var(Y(:,q));
                   end
                   es(js) = mean(E_all3);                  
             end
           %@@@@@@@@@@@@@@@@@@@@@@@@@@@
                 
                 
                    %@@@@@@@@@@@@@@@@@@@@@@@@@@@
             if  (  abs(tdist) < .04 && abs(sdist) < .2 && Nta==Ntb && ~sameEsameT ) 
                %   if ~sameEsameT 
                    % similar time, same size data set, similar location
                    jts = jts+1;
                    % [EE,E,ssa,ssb]  % print coordinates of overlap
                % ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~ %
                     % Seperate input and output
                       
                        N = 2*floor(floor(Nta/2)/2); %split data set in half. N must be even
                        X = Ea{ssa}(1:N,1:end-1);
                        Y = Ea{ssa}(end-N+1:end,1:Q);       
                  % Initialize some Wiener Filter Parameters
                  [N,P]=size(X); [No,Q]=size(Y); y_all = zeros(No,Q);
                    for q=1:Q % loop over output dimensions
                        for i=1:P % loop over input dimensions
                            y_t = conv(X(1:No,i),W_allE{E}{ssb}(1+(i-1)*M:i*M,q));  % use archived filter from other elephant
                            y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
                        end       
                   end    % end loop over q
                % ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ %
                   for q = 1:2;
                      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./std(Y(:,q));
                    %      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./var(Y(:,q));
                   end
                   ets(jts) = mean(E_all3);                  
             end
           %@@@@@@@@@@@@@@@@@@@@@@@@@@@
           
           
                    %@@@@@@@@@@@@@@@@@@@@@@@@@@@
             if  (  abs(tdist) < .04 &&  abs(pdist) < .2 && Nta==Ntb && ~sameEsameT ) %  abs(tdist) < .1 && 
                %   if ~sameEsameT 
                    % similar time, same size data set, similar location
                    jtp = jtp+1;
                    % [EE,E,ssa,ssb]  % print coordinates of overlap
                % ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~ %
                     % Seperate input and output
                       
                        N = 2*floor(floor(Nta/2)/2); %split data set in half. N must be even
                        X = Ea{ssa}(1:N,1:end-1);
                        Y = Ea{ssa}(end-N+1:end,1:Q);       
                  % Initialize some Wiener Filter Parameters
                  [N,P]=size(X); [No,Q]=size(Y); y_all = zeros(No,Q);
                    for q=1:Q % loop over output dimensions
                        for i=1:P % loop over input dimensions
                            y_t = conv(X(1:No,i),W_allE{E}{ssb}(1+(i-1)*M:i*M,q));  % use archived filter from other elephant
                            y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
                        end       
                   end    % end loop over q
                % ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ %
                   for q = 1:2;
                      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./std(Y(:,q));
                    %      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./var(Y(:,q));
                   end
                   etp(jtp) = mean(E_all3);                  
             end
           %@@@@@@@@@@@@@@@@@@@@@@@@@@@
           
           
                    %@@@@@@@@@@@@@@@@@@@@@@@@@@@
             if  (  abs(pdist) < .2 && abs(sdist) < .2 && Nta==Ntb && ~sameEsameT ) %  abs(tdist) < .1 && 
                %   if ~sameEsameT 
                    % similar time, same size data set, similar location
                    jps = jps+1;
                    % [EE,E,ssa,ssb]  % print coordinates of overlap
                % ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~ %
                     % Seperate input and output
                       
                        N = 2*floor(floor(Nta/2)/2); %split data set in half. N must be even
                        X = Ea{ssa}(1:N,1:end-1);
                        Y = Ea{ssa}(end-N+1:end,1:Q);       
                  % Initialize some Wiener Filter Parameters
                  [N,P]=size(X); [No,Q]=size(Y); y_all = zeros(No,Q);
                    for q=1:Q % loop over output dimensions
                        for i=1:P % loop over input dimensions
                            y_t = conv(X(1:No,i),W_allE{E}{ssb}(1+(i-1)*M:i*M,q));  % use archived filter from other elephant
                            y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
                        end       
                   end    % end loop over q
                % ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ %
                   for q = 1:2;
                      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./std(Y(:,q));
                    %      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./var(Y(:,q));
                   end
                   eps(jps) = mean(E_all3);                  
             end
           %@@@@@@@@@@@@@@@@@@@@@@@@@@@
           
           
           
           
                    %@@@@@@@@@@@@@@@@@@@@@@@@@@@
             if  (  abs(tdist) < .04 && abs(pdist) < .2 && abs(sdist) < .2 && Nta==Ntb && ~sameEsameT )  
                %   if ~sameEsameT 
                    % similar time, same size data set, similar location
                    jtps = jtps+1;
                    % [EE,E,ssa,ssb]  % print coordinates of overlap
                % ~~~~~~~~Filter using ALL input signals~~~~~~~~~~~~~~~~~~~~~ %
                     % Seperate input and output
                       
                        N = 2*floor(floor(Nta/2)/2); %split data set in half. N must be even
                        X = Ea{ssa}(1:N,1:end-1);
                        Y = Ea{ssa}(end-N+1:end,1:Q);       
                  % Initialize some Wiener Filter Parameters
                  [N,P]=size(X); [No,Q]=size(Y); y_all = zeros(No,Q);
                    for q=1:Q % loop over output dimensions
                        for i=1:P % loop over input dimensions
                            y_t = conv(X(1:No,i),W_allE{E}{ssb}(1+(i-1)*M:i*M,q));  % use archived filter from other elephant
                            y_all(:,q) = y_all(:,q) + y_t(M:end); % actual prediction
                        end       
                   end    % end loop over q
                % ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ %
                   for q = 1:2;
                      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./std(Y(:,q));
                    %      E_all3(q) = mean( (Y(:,q)-y_all(:,q)).^2)./var(Y(:,q));
                   end
                   etps(jtps) = mean(E_all3);                  
             end
           %@@@@@@@@@@@@@@@@@@@@@@@@@@@
    
            end
        end
        
Sdepth(EE,E,:)=[length(en),length(et),length(es),length(ep),...
          length(ets),length(etp),length(eps),length(etps),length(eg),length(ega)];   
ErrE(EE,E,:)=[nanmedian(en),nanmedian(et),nanmedian(es),nanmedian(ep),...
          nanmedian(ets),nanmedian(etp),nanmedian(eps),nanmedian(etps),...
          nanmedian(eg), nanmedian(ega)]; 
      
      end
end

% save CrossETdata;
%%
% save CrossEdata Sdepth ErrE Sdepths ErrEs

[K,K,Fs] = size(ErrE);

load CrossETdata;

load null_pred;

ErrEb = ErrE;
ErrEn = ErrE;
newdat = zeros(K^2,Fs);

Di = logical(diag(ones(1,K)));
% % Speicfically exclude outlyier elephants #4 #9 (Ndrobo and Ngalatoni)
% N4 = zeros(13,13); N4(:,4) = ones(13,1); N4(4,:) = ones(1,13);
% N9 = zeros(13,13); N9(:,9) = ones(13,1); N9(9,:) = ones(1,13);
% N49 = N4|N9;

for j=1:Fs
    Errc = ErrE(:,:,j); % matrix is equal to orig data structure
   % Errc(N49) = NaN;  % except Nagaltoni and Nadrobo are removed
 
     sm = mean(mean(Sdepth(:,:,j)));  
     Errc(Sdepth(:,:,j)<.25*sm) = NaN; % .25  Resrtict to require 25% of mean sampling depth 
    %Errc(Errc>10) = NaN; % Restrict to require MSE < 10.  Probably a bad idea.    
    
    ErrEn(:,:,j) = Errc; % this is stored as ErrEn structure (used for self E comparison)  
       nn(:,j) = reshape(Errc,K^2,1); 
    
     Errc(Di) = NaN*ones(1,K); % also remove diagnol 
    ErrEb(:,:,j) = Errc;  % This is stored as ErrEb,(for crossE comparison)
    
    newdat(:,j) = reshape(Errc,K^2,1); % stack 13 by 13 instead of repeated medieans.
 
end


% fig3b = [newdat(:,1),newdat(:,3),newdat(:,4),newdat(:,5),newdat(:,9)];
% figure(4); clf; boxplot(fig3b);

%%
% figure(1); clf; boxplot(bar1); ylim([0,10]);
% xlabels = {'no restriction','same elephant','time +/- 3mo','season +/- 20%','position +/- 20%',...
%     'time and season','time and position','position and season','time,position,season',...
%     'null model'}
% set(gca,'Xtick',1:10,'XTicklabel',xlabels); ylabel('normalized MSE');
% 
% xlabels = {'no const.','self','time (t)','season (s)','position (p)',...
%     't & s','t & p','p & s','t p & s','null'}
%    set(gcf,'color','w'); ylabel('normalized MSE','FontSize',12); 
%    set(gca,'fontsize',12);


   
   bar2 = zeros(K,Fs); 
   for j=1:Fs
       bar2(:,j) = diag(ErrEn(:,:,j));
   end
     bar2 = [bar2,m_err];
     
% % constrainted to be same elephant
% sxlabels = {'no const.','time (t)','season (s)','position (p)',...
%     't & s','t & p','p & s','t p & s','null'}
% figure(2); clf; boxplot(bar2); ylim([0,10]);
% set(gca,'Xtick',1:Fs,'XTicklabel',xlabels); ylabel('normalized MSE');
%    set(gcf,'color','w'); ylabel('normalized MSE','FontSize',12); 
%    set(gca,'fontsize',12);
% 


bar1 = nanmedian(ErrEb); K =13;
bar1 = reshape(bar1,K,Fs); 
xlabels = {'no constraint',' ','same time',' ','same season',' ','nearby',' ','all constraints',' ','null model'};
C = [1,2,1,2,1,2,1,2,1,2,3];

fig3 = [bar1(:,1),bar2(:,1),bar1(:,2),bar2(:,2),bar1(:,3),bar2(:,3),...
    bar1(:,4),bar2(:,4),bar1(:,8),bar2(:,8),m_err];
colormap('cool');
figure(3); clf; boxplot(fig3,'plotstyle','compact','labels',xlabels,'colorgroup',C,'colors','rgbm');
%figure(3); clf; boxplot(fig3,'boxstyle','filled','labels',xlabels,'labelorientation','inline','colorgroup',C);
ylim([0,10]); ylabel('Normalized MSE'); set(gcf,'color','w');


% fig3a = [bar1(:,1),bar2(:,1),bar1(:,3),bar2(:,2),bar1(:,4),bar2(:,3),...
%     bar1(:,5),bar2(:,4),bar1(:,9),bar2(:,8),m_err];
% fig3b = [bar1(:,1),bar2(:,1),bar1(:,3),bar2(:,2),bar1(:,4),bar2(:,3),...
%     bar1(:,5),bar2(:,4),bar1(:,9),bar2(:,8),m_err];
% 


alllabels = {'no constraint','same time (t)','same season (s)','nearby (p)',...
    'ts','tp','sp','tsp', '>t','>t,<sp', 'self, no const.','self t','self s','self p',...
    'self ts','self tp','self sp','self tsp','self >t','self >t,<sp','null model'};

figure(1); clf; boxplot([bar1,bar2],'plotstyle','compact','labels',alllabels);
ylim([0,10]); ylabel('Normalized MSE'); set(gcf,'color','w');

CE_Data =[];
for j=1:Fs
    CE_Data = [CE_Data; ErrEn(:,:,j)];
end
folder = '/Users/alistair/Documents/Berkeley/Getz Lab';

 dlmwrite([folder,'/CrossET_data2.txt'],CE_Data);

 
 % save filt_gen_data-110509