%%        Compute Bounding Ellipse and NDVI plot for K elephants
% Alistair Boettiger                                   Date Begun: 02/25/08
% Getz Lab                                         Complete Since: 03/11/08
% Functionally Complete                             Last Modified: 12/03/09

% bnd_ellipse_single.m
% called by null_model_ellipse.m
%
% Notes:
% Computes bounding ellipses for elephant
% can show dynamic plots of elephant motion over time with changing
% background of local NDVI values (duplicated into elephant_movie.m).
%
% 03/13/08 changes:
%  *  ellipse orientations are now given relevant to  trajectory of last 
%        hour's motion rather than x-axis.   
%
%
%



function [xcm, ycm, ra, rb, o] = bnd_ellipse_single(Elongs,Elats,his)

% % Parameters for autonomous execution

% Elongs = xnull; Elats = ynull; his = 24;

T = length(Elongs)-his;

ex=zeros(his,1); ey=zeros(his,1); 
xcm = zeros(T,1); ycm = zeros(T,1);
ra = xcm; rb = xcm; o = xcm;
res = 500; % length scale of grid on which to resolve positions.  

% compute COMs and Bounding Ellipses for all elephants
for t=1:T%  t = 13000
%   % rows with a % in the leading column are plotting commands;  
%     ni = Nind(t);  figure(1); clf; pcolor(long,lat,NDVI(:,:,ni)); shading flat;  hold on; 
      ex=nonzeros(Elongs(t:t+his-1)); % nonzeros -- don't use mising data points in computing stats
      ey=nonzeros(Elats(t:t+his-1));
     if  length(ex) > 2; % sum(ex)~=0;  % computing densities with fewer than 2 points leads to irregularities 
      xcm(t) = mean(ex); ycm(t) = mean(ey);  % compute COMs in lab frame
%       plot(ex, ey, esym(k),'Color',[1-k/25,1-k/25,1-k/25]); % plot elephant postions with distinct symbols and colors      
      % Transform to raster data elephant by elephant
        lx = min(ex); ux = max(ex); xs = linspace(lx,ux,res); % scale vectors of raster plot 
        ly = min(ey); uy = max(ey); ys = linspace(ly,uy,res);   
        lex = length(ex); % need size of vector to construct raster mapping matrices
        Xs = meshgrid(xs,[1:lex]); Ys = meshgrid(ys,[1:lex]); % Matrices to avoid computational loops 
        Ex = meshgrid(ex,[1:res]); Ey = meshgrid(ey,[1:res]); % Matrices to avoid computational loops
        P = uint8(zeros(res)); % reinitialize label matrix
        [exs exi] = min(abs(Xs' - Ex));   [eys eyi] = min(abs(Ys' - Ey));
        for i=1:lex % I can't believe this needs to be a loop.  flags the postions, (eyi exi), in the labeling matrix with 1s
            P(eyi(i), exi(i)) = 1; % create labeled matrix in raster format
        end;
        % figure(2); clf; pcolor(xs,ys,double(P)); shading flat; colormap(gray);% check transformation
        % hold on; plot(xcm(t),ycm(t)) 
        % compute Bounding ellipse
        stats = regionprops(P,'MajorAxisLength','MinorAxisLength','Orientation');
        ra(t) = stats.MajorAxisLength; 
        rb(t) = stats.MinorAxisLength;
        o(t) = stats.Orientation;             
%       % plot density ellipses  (this should actually work now, good for debugging) 
        xsc = (ux-lx)/res; ysc = (uy-ly)/res; % scaling factors for conversion
%         a = linspace(-ra(t,k)/2*xsc,ra(t,k)/2*xsc,10);
%         b = linspace( -rb(t,k)/2*ysc,rb(t,k)/2*ysc,10);
%         xa = xcm(t,k) + a*cos(o(t,k)); ya = ycm(t,k) + a*sin(o(t,k));
%         xb = xcm(t,k) + b*cos(o(t,k)); yb = ycm(t,k) - b*sin(o(t,k));
%         figure(1); hold on; plot(xa,ya,'Color','c');
        ra(t) = ra(t).*( sqrt(ysc^2*sin(o(t))^2+xsc^2*cos(o(t))^2) ); 
        rb(t) = rb(t).*( sqrt(ysc^2*cos(o(t))^2+xsc^2*sin(o(t))^2) ); 
        %[1-k/25,1-k/25,1-k/25]); 
%         plot(xb,yb,'Color',[1-k/25,1-k/25,1-k/25]);  
     % % change reference angle for orientation
        % compute current direction
        try  % errors for t=1.  Hopefully this is faster than if t>1...
        theta = atan2((ycm(t,k)-ycm(t-1,k)),(xcm(t,k)-xcm(t-1)));
            o(t) = o(t) - theta; 
        catch
        end
     end
end       
%  title(dates(t));
%  % legend('Goya','Maya','Stratus','Ngalatoni','Neptune','Aztec','Maua','Amina','Ndorobo','Monsoon','Jerusalem','Rosemary');
%  pause(.001);



