%                         Null Model
% Alistair Boettiger                                   Date Begun: 07/20/09
% Getz Lab                                       Functional Since: 07/22/09
% Functionally Complete                             Last Modified: 07/22/09
%
% 
%  
%
%Notes:  Create an AR(1) null model with statistics matching elephant
%motion within the 1000 hr prediction period.  


clear all; close all;
K=13; % number of pachederms 

 load e_stats4 xcm ycm  % import results from COM tracking
T2 = length(xcm) - 2*24; % length of inputs and outputs 
err = cell(K,1); data = cell(K,1); med_err = zeros(K,1); 

% find time at which each elephant starts recording and stops recording
[jnk t1] = max(xcm>0); % sets all nonzero elements to 1, max returns first of equivelant maxes 
[jnk tend] = max(flipud(xcm)>0);
tend = length(xcm)-tend+1;


    % convert inputs with missing data to NaN flags
    %     (this avoids upsetting min max rescaling, difference calcs, etc)
    Xcm = xcm;  Xcm(xcm==0)=NaN;
    Ycm = ycm;  Ycm(ycm==0)=NaN;


 
for E = 1:K     % loop through elephant on which to center analysis
     Ti = t1(E); % restrict time to interval for choice elephant
     Te = tend(E); %
   
   % Normalize the choice elephant's stats too
    xcn = mapo1t1(Xcm(Ti:Te,E));
    ycn = mapo1t1(Ycm(Ti:Te,E));
    in = [xcn,ycn];
    


% Flag start and end points of gaps
    flag = isnan(xcn);  flag = flag(2:end)-flag(1:end-1);
    sis = find(flag==1); % start points of gaps
    ses = find(flag==-1); % end points of gaps
    ses = [0; ses]; % we want to pull out the data not the gaps
    sis = [sis; length(in(:,1))]; % 0 to 1st gap start is the first data segment 
%      % plot data and mark gaps
%         figure(1); clf; plot(xcn);
%         hold on; plot(sis, zeros(1,length(sis)),'c.'); 
%         plot(ses,zeros(1,length(sis)),'r.');
        N=length(xcn);
        segs = length(sis);
    B = 1000; % batch size;    
    kk=0;
    
    for j=1:segs
        temp = in(1+ses(j):sis(j),:);  % split out across gaps
        JJ = ceil(length(temp)/B);
        for jj=1:JJ % separate gap sections into regions at most B long
            kk=kk+1;
            data{kk}=  temp(1+(jj-1)*B:min(jj*B,length(temp)),:);
        
        
        
        end
    end

    
    err{E} = zeros(length(data),1); 
     for kk=1:length(data); 
                 dx = diff(data{kk}(:,1));
                 dy = diff(data{kk}(:,2)); 
                    
                    rx = xcorr(dx); 
                    ry = xcorr(dy);
                     sp = (length(rx)+1)/2;
                     rx = rx(sp:end); n = length(rx);
                     ry = ry(sp:end); 
                     
                  %  figure(1); clf; plot(rx);
                    
                    xvar = nanvar(dx); 
                    yvar = nanvar(dy);
                    
                    % m_step = nanmean(sqrt(dx.^2+dy.^2)); % mean stepsize for this elephant
                    % s_step = nanstd(sqrt(dx.^2+dy.^2)); % std stepsize for this elephant

      %  figure(2); clf; plot(data{kk}(:,1),data{kk}(:,2));  
        xdata = 1:length(rx);
        [parx,model] =  fitexpf(xdata,rx');
        [pary,model] =  fitexpf(xdata,ry');
%         fit = parx(1)*exp(-parx(2)*(1:n));
%         figure(1); clf; plot(rx,'b'); hold on; 
%         plot(fit,'r');
        
        % X(n) = c + a*X(n-1) + w;  
        % w is white noise mean zero variance sigma^2;
        % mu = c/(1-a)
        % var = sigma^2/(1-a^2)
        
        ax = exp(-1*parx(2)); % 
        sigma2x = sqrt(xvar/(1-ax^2))/(2*pi); 
        ay = exp(-1*pary(2)); % 
        sigma2y = sqrt(yvar/(1-ay^2))/(2*pi); 
     
             % just predict for 2nd half of positions.  
        st = floor(n/2); en = ceil(n/2); 
        xns = zeros(1,en);
        xnull = zeros(1,en);
        yns = zeros(1,en);
        ynull = zeros(1,en); 
        
   
        xnull(1) = data{kk}(st,1); ynull(1) = data{kk}(st,2);
        xns(1) = sigma2x*randn;
        yns(1) = sigma2y*randn;
        for i=1:en-1 
            xns(i+1) = ax*xns(i) + sigma2x*randn;
            yns(i+1) = ay*yns(i) + sigma2y*randn;
             xnull(i+1) = xnull(i) + xns(i+1); 
             ynull(i+1) = ynull(i) + yns(i+1); 
%            xnull(i+1) = data{kk}(i,1) + xns(i+1); 
 %           ynull(i+1) = data{kk}(i,2) + yns(i+1); 
        end
        
   %     figure(2); hold on; plot(xnull,ynull,'r'); 
        
        
       % pdata = var(mean(data{kk},2)); 
        
        pdata = std(mean(data{kk},2)); 
        err{E}(kk) = mean( (data{kk}(st+1:n,1)-xnull').^2+(data{kk}(st+1:n,2)-ynull').^2 )/pdata;
        
        
        clear model n; 
        
%           % confirm simulated data has same statistics
%                     rxb = xcorr(xns);                    
%                      rxb = rxb(sp:end);
%                     figure(1); clf; plot(rxb);
%                     [parxb,model] =  fitexpf(xdata,rxb);
     end
      med_err(E) = median(err{E});

end % end loop through elephants
 

m_err = zeros(K,1);
for E=1:K
   m_err(E) = mean(err{E}); 
end
mean(m_err)
median(m_err)
std(m_err)

 save null_pred m_err err;


   